[Mesa-dev] [PATCH] egl: Return EGL_BAD_MATCH for invalid profile attributes

Matt Turner mattst88 at gmail.com
Mon Oct 8 17:02:54 PDT 2012


Version 12 of the EGL_KHR_create_context spec changed this behavior.
---
 src/egl/main/eglcontext.c |   17 +++++++----------
 1 files changed, 7 insertions(+), 10 deletions(-)

diff --git a/src/egl/main/eglcontext.c b/src/egl/main/eglcontext.c
index 71eca6f..4efb76b 100644
--- a/src/egl/main/eglcontext.c
+++ b/src/egl/main/eglcontext.c
@@ -229,17 +229,14 @@ _eglParseContextAttribList(_EGLContext *ctx, _EGLDisplay *dpy,
              *
              *     "* If an OpenGL context is requested, the requested version
              *        is greater than 3.2, and the value for attribute
              *        EGL_CONTEXT_PROFILE_MASK_KHR has no bits set; has any
              *        bits set other than EGL_CONTEXT_CORE_PROFILE_BIT_KHR and
              *        EGL_CONTEXT_COMPATIBILITY_PROFILE_BIT_KHR; has more than
              *        one of these bits set; or if the implementation does not
              *        support the requested profile, then an
              *        EGL_BAD_PROFILE_KHR error is generated."
              *
              * However, it does not define EGL_BAD_PROFILE_KHR.  For now use
              * EGL_BAD_ATTRIBUTE.
              */
-            err = EGL_BAD_ATTRIBUTE;
+            err = EGL_BAD_MATCH;
             break;
          }
       }
@@ -229,17 +229,14 @@ _eglParseContextAttribList(_EGLContext *ctx, _EGLDisplay *dpy,
              *     "* If an OpenGL context is requested, the requested version
              *        is greater than 3.2, and the value for attribute
-             *        EGL_CONTEXT_PROFILE_MASK_KHR has no bits set; has any
-             *        bits set other than EGL_CONTEXT_CORE_PROFILE_BIT_KHR and
-             *        EGL_CONTEXT_COMPATIBILITY_PROFILE_BIT_KHR; has more than
-             *        one of these bits set; or if the implementation does not
-             *        support the requested profile, then an
-             *        EGL_BAD_PROFILE_KHR error is generated."
-             *
-             * However, it does not define EGL_BAD_PROFILE_KHR.  For now use
-             * EGL_BAD_ATTRIBUTE.
+             *        EGL_CONTEXT_OPENGL_PROFILE_MASK_KHR has no bits set; has
+             *        any bits set other than EGL_CONTEXT_OPENGL_CORE_PROFILE_BIT_KHR
+             *        and EGL_CONTEXT_OPENGL_COMPATIBILITY_PROFILE_BIT_KHR; has
+             *        more than one of these bits set; or if the implementation does
+             *        not support the requested profile, then an EGL_BAD_MATCH error
+             *        is generated."
              */
-- 
1.7.8.6



More information about the mesa-dev mailing list